@@ -4,6 +4,8 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 9 MB (so use with caution, and patience).
 #'
+#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
+#'
 #' @format \code{sf} data frame with 206 rows of 10 variables + geometry
 #'
 #' \describe{
@@ -26,7 +28,7 @@
 #'
 #' @export
 
-orp_polygony <- function() {
+orp_polygony <- function(method = "curl") {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -48,7 +50,7 @@ orp_polygony <- function() {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, quiet = T)
+      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
     }
   }
 
