@@ -4,6 +4,8 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 1 MB.
 #'
+#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
+#'
 #' @format \code{sf} data frame with 6.198 rows of 4 variables + geometry:
 #'
 #' \describe{
@@ -17,7 +19,7 @@
 #'
 #' @export
 
-reky <- function() {
+reky <- function(method = "curl") {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -39,7 +41,7 @@ reky <- function() {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, quiet = T)
+      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
     }
   }
 
